[−][src]Enum ron_crdt::atom::Atom
An Atom in RON is an immutable value of one of the types: UUID, integer, string and float.
Variants
UUID(UUID)References another object
Integer(i64)Signed integer. RON specifies arbitrary precision integer, we only support up to 64 bits.
Float(f64)IEEE 754 Floating point number.
String(String)UTF-8 String
Methods
impl Atom[src]
pub fn is_uuid(&self) -> bool[src]
Return true if and only if this is an UUID atom.
pub fn is_integer(&self) -> bool[src]
Return true if and only if this is an Integer atom.
pub fn is_float(&self) -> bool[src]
Return true if and only if this is a Float atom.
pub fn is_string(&self) -> bool[src]
Return true if and only if this is a String atom.
pub fn parse<'a>(
input: &'a str,
context: Option<(&UUID, &UUID)>
) -> Option<(Self, &'a str)>[src]
input: &'a str,
context: Option<(&UUID, &UUID)>
) -> Option<(Self, &'a str)>
Parse a single atom, returning the Atom and the remaining string. If context is not
None UUID Atoms may be compressed against (previous column UUID / previous row UUID).