[−][src]Enum ron_crdt::op::Terminator
Op terminator
Variants
RawRaw ops are stand-alone within a frame.
QueryQuery ops, as well as reduced ops following them, create a chunk in a frame.
HeaderHeader ops, as well as reduced ops following them, create a chunk in a frame.
ReducedReduced ops belong to the query/header op before them.
Methods
impl Terminator[src]
pub fn from_string(inp: &str) -> Result<Terminator, &'static str>[src]
Parse a terminator from inp.
pub fn from_char(inp: char) -> Result<Terminator, &'static str>[src]
Parse a terminator from inp.