pub struct LWW;Expand description
An LWW is an associated map from UUIDs to Atoms. Conflicting writes are merge by using the Op event timestamp. The last writes wins.
pub struct LWW;An LWW is an associated map from UUIDs to Atoms. Conflicting writes are merge by using the Op event timestamp. The last writes wins.