[−][src]Struct ron_crdt::Set
2-Phase sets are sets of atoms.
Each element is associated with the timestamp of the Op that inserted it. Removing elements is done my inserting a tombstone. Thus, deletions override insertions.
Methods
impl Set[src]
pub fn insert<'a>(state: &Frame<'a>, value: Atom) -> Option<Frame<'a>>[src]
Inserts value into the Set state. Returns the update Frame without modifying the Set.
pub fn remove<'a>(state: Frame<'a>, value: &Atom) -> Option<Frame<'a>>[src]
Removes value from the Set state by inserting a tombstone for all insertions of
value. Returns the update Frame without modifying the Set.